import { RootItemConfig } from '@genesis-community/golden-layout';
import { FoundationElement } from '@microsoft/fast-foundation';
import { LayoutComponent, Placement, RegisteredElementConfig, RegistrationConfig, SerialisedLayout, componentType } from '../utils/';
export { layoutStyles } from '../styles';
/**
 * @public
 * Top level web component which is used to initialise a custom layout
 * @remarks
 * Can be used in a composition to customise the styles of the layout.
 * @tagname %%prefix%%-layout
 */
export declare class FoundationLayout extends FoundationElement implements LayoutComponent {
    private layout;
    /** @internal */
    layoutElement: HTMLElement;
    private layoutConfig;
    /** @internal */
    [componentType]: "root";
    /**
     * Number describing how long to wait in ms before reloading the config when adding items
     * declaratively by the html API. Default 500 (ms).
     * @public
     */
    reloadBuffer: number;
    private reloadPending;
    private registeredComponents;
    /** @internal */
    private uuid;
    /** @internal */
    private session;
    /**
     * Attribute which if set will auto save and load the layout as the user changes it.
     * Omit this attribute to disable this feature.
     * Set attribute using `auto-save-key`.
     * @public
     */
    autoSaveKey?: string;
    /**
     * Function which is used to generate the placeholder text when a layout is loaded
     * with a missing item.
     * @public
     */
    missingItemPlaceholder: (missingItem: string) => string;
    /**
     * Boolean signifies whether the layout has loaded for the first time or not.
     * @remarks
     * When using the declarative API this is set to true when the layout loads after the first
     * timeout of `reload-buffer`. If using the JavaScript API this occurs after the first call
     * to {@link FoundationLayout.addItem | addItem()}.
     *
     * When using the `LifecycleMixin`, the mixin can be used to gate lifecycle methods from
     * running before the items are inside of the layout.
     * @public
     */
    hasFirstLoaded: boolean;
    /** @internal */
    usingDeclerativeAPI: boolean;
    /**
     * @public
     * Set to true when the user is currently dragging the panes inside of the layout
     */
    dragging: boolean;
    /** @internal */
    constructor();
    /** @internal */
    connectedCallback(): void;
    /** @internal */
    disconnectedCallback(): void;
    /** @internal */
    private onDragStart;
    /** @internal */
    private onDragStop;
    /** @internal */
    private onItemAdded;
    /** @internal */
    private onItemRemoved;
    /** @internal */
    private onItemResized;
    /**
     * JS API, public
     */
    /**
     * @public
     * Gets all of the required element registry function names for a set of config
     * @remarks
     * You can use this with {@link FoundationLayout.registeredItems | registeredItems} to work out what items you need to register with {@link FoundationLayout.registerItem | registerItem()}
     * before loading the layout with {@link FoundationLayout.loadLayout | loadLayout()}
     *
     * @param layout - any version of {@link SerialisedLayout} object describing the layout
     * @returns string[] - an item for each registered element in the config. These must all be added before {@link FoundationLayout.loadLayout | function}
     * @throws - various errors if the layout parameter cannot be parsed
     */
    static layoutRequiredRegistrations(layout: SerialisedLayout): string[];
    /**
     * @public
     * Gets all of the currently registered names
     * @remarks
     * You can use this with {@link FoundationLayout.layoutRequiredRegistrations | layoutRequiredRegistrations} to work out what items you need to register with {@link FoundationLayout.registerItem | registerItem()}
     * before loading the layout with {@link FoundationLayout.loadLayout | loadLayout()}
     *
     * @returns string[] - an item for each registered element currently registered with the layout system
     */
    registeredItems(): string[];
    /**
     * @public
     * Gets a minified string containing the config describing the current layout of the layout object to later restore in {@link FoundationLayout.loadLayout | function}
     * @returns - latest version of {@link SerialisedLayout} describing the layout
     */
    getLayout(): SerialisedLayout;
    /**
     * Try to load a layout from local storage, or return false. Only required if manually calling {@link FoundationLayout.registerItem}
     * @remarks
     * Attempt to load an autosaved layout from local storage, keyed on the `auto-save-key` attribute.
     * If `auto-save-key` attribute is not set or there is no autosaved layout yet, this will return false. Else, true.
     *
     * This function is automatically called when loading the layout via the declarative API so if you're not registering components via
     * the JavaScript API then you don't need to call this function. If you *are* calling {@link FoundationLayout.registerItem} then you should call this function immediately afterwards.
     *
     * Will load the layout with `handleMissingItem = 'placeholder` so placeholder text will be shown for any missing items.
     * @returns boolean - true if a layout was loaded, false if not
     * @public
     */
    tryLoadLayoutFromLocalStorage(): boolean;
    /**
     * @public
     * Restores a layout described in the config from {@link FoundationLayout.getLayout | getLayout()}
     *
     * @remarks
     * In order to restore a layout you must have registered all of the required panes with the layout system before restoring it. If you are just setting the layout using the declarative API then all of the same components will be registered. If you have added any elements using {@link FoundationLayout.registerItem} then you must ensure all of the same items have been added again. To make tracking what items are registered easier it is recommended in this case you explicitly name your registrations using the `id` parameter available on the {@link RegisteredElementConfig} and `foundation-layout-item` APIs. You can use {@link FoundationLayout.layoutRequiredRegistrations} to check which items are registered in a current layout in order to dynamically add any missing items before you can restore the layout
     *
     * @param layout - any version of {@link SerialisedLayout} object describing the layout
     * @param handleMissingItem - what to do if the layout contains items that are not currently registered with the layout system. Defaults to 'error' which will throw an error. If set to 'placeholder' then any missing items will be replaced with a placeholder element. You can control the text of the placeholder element with {@link FoundationLayout.missingItemPlaceholder}.
     * @throws {@link LayoutUsageError} if you attempt to load a layout with registered items that are not currently registered with the layout system, and handleMissingItem is set to 'error' (default).
     * @throws various errors if the layout string is malformed and cannot be parsed
     */
    loadLayout(layout: SerialisedLayout, handleMissingItem?: 'placeholder' | 'error'): void;
    /**
     * @public
     * Dynamically add a new item to the layout. The user can move the new plane to whenever they want once it has been added.
     * @remarks
     * Adding a new item invokes the registration previously made explicitly via {@link FoundationLayout.registerItem | registerItem()} or implicitly via the html declerative API.
     *
     * The elements added onto the new pane are copies using `element.cloneNode()` of the original element references used during registration.
     *
     * @param config - {@link RegisteredElementConfig} configuration items for the new pane
     * @param placement - where to add the new pane on the layout (defaults to the right hand side)
     * @throws {@link LayoutRegistrationError} if you attempt to add an item before it has been registered
     */
    addItem(config: RegisteredElementConfig, placement?: Placement): void;
    /**
     * @public
     * Register a collection of `Element` and associate them with an `ID` with the layout system for later use.
     * @remarks
     * You would use this to register elements that you later want to load when using {@link FoundationLayout.loadLayout}.
     * Use {@link FoundationLayout.layoutRequiredRegistrations} to see what components need to be registered for a certain config
     * and then register them using this function before calling {@link FoundationLayout.loadLayout}.
     *
     * When registering an element it is moved by reference into the internals of the layout, so if you pass elements already in the DOM then they will disappear. If you want to avoid this you can pass copies using `element.cloneNode(true)`.
     *
     * @param registration - string of the registration ID
     * @param elements - Elements[] containing the reference to the elements to register for later usage
     * @throws {@link LayoutUsageError} if you attempt to add an item before the layout has been initialised.
     * @throws {@link LayoutRegistrationError} if you attempt to use a `registration` name which is already in use (declarative html API and JavaScript API registrations use the same "pool" of registration names).
     * @returns - string defining the name of the registered item with the layout system (config.id if set).
     */
    registerItem(registration: string, elements: Element[]): string;
    /**
     * Internal APIs
     */
    /**
     * Request to reload the layout using the private member config. Debounced using the time set
     * in this.reloadBuffer
     * @internal
     */
    requestLayoutReload(): void;
    /**
     * Adds a config item into the root config and returns a link to the new config in the tree
     * @typeParam T - RowOrColumnItemConfig | StackItemConfig | ComponentItemConfig;
     * @param item - T to add as the root element of the layout
     * @returns T the reference to the added item in the whole item config
     * @throws {@link LayoutUsageError} if you try and add an item when a root has already been set (this happens if you have multiple direct children of this html element which is an incorrect usage)
     * @internal
     */
    addItemFromChild<T extends RootItemConfig>(item: T): T;
    /**
     * Registers a function with golden layout to create a pane
     * @param elements - Elements[] to add to new new pane
     * @param id - optional string which is used to register the new function with golden layout. Defaults to sequentially setting the IDs for default items
     * @returns - string which is the registered ID
     * @throws - {@link LayoutRegistrationError} if the id is already in use
     * @internal
     */
    cacheElementsAndRegister({ elements, id }: RegistrationConfig): string;
    /**
     * Sets up the event listeners for the layout receive events
     * @internal
     */
    private setupLayoutReceiveEvents;
    /**
     * Saves the stored layout config according to the Golden Layout provider.
     * And caches the layout in local storage if {@link FoundationLayout.autoSaveKey} is set.
     * @internal
     * */
    private cacheAndSaveLayout;
    /**
     * Used when we are trying to load a layout with missing registrations and we want to add placeholder items
     * @remarks
     * This function will register the items with placeholder text, and set them to be closeable if they were not already
     * As config is passed by reference it is updated directly
     * @param config - The layout config to update
     * @param missingRegisteredItems - The items which were missing from the registrations
     * @internal
     */
    private registerPlaceholdersAndSetClosable;
    /**
     * Loads the provided config into Golden Layout and does other setup
     * @remarks
     * Loads the config into Golden Layout, and then sets up the event listeners for the layout
     * When loading the layout the visual configuration is loaded
     * Event listeners are added to the drag handles to emulate resizing events
     *
     * **This is the only function which should call this.layout.loadLayout() directly.**
     * @internal
     */
    private loadGLConfigAndSetup;
}
/**
 * `ViewTemplate` which defines the html for {@link FoundationLayout}.
 * @remarks
 * Can be used in a composition to customise the styles of the layout.
 * @public
 */
export declare const layoutTemplate: import("@microsoft/fast-element").ViewTemplate<FoundationLayout, any>;
/**
 * The Foundation Layout Composed element
 *
 * @internal
 * @remarks
 * Can be registered with the design system via {@link foundationlayoutComponents}.
 *
 * Tag Name: <{prefix}-layout>
 */
export declare const foundationLayout: (overrideDefinition?: import("@microsoft/fast-foundation").OverrideFoundationElementDefinition<{
    baseName: string;
    styles: import("@microsoft/fast-element").ElementStyles;
    template: import("@microsoft/fast-element").ViewTemplate<FoundationLayout, any>;
}>) => import("@microsoft/fast-foundation").FoundationElementRegistry<{
    baseName: string;
    styles: import("@microsoft/fast-element").ElementStyles;
    template: import("@microsoft/fast-element").ViewTemplate<FoundationLayout, any>;
}, typeof FoundationLayout>;
//# sourceMappingURL=layout-main.d.ts.map