import { ResolvedLayoutConfig } from '@genesis-community/golden-layout';
import { componentType } from './constants';
/**
 * @public
 * Versioned layout config objects. `v` is the version and `c` contains the layout config.
 * @remarks
 * Versioning the layout config in this way allows changes to the config schema while
 * remaining backwards compatible with any existing client/user configurations. When loading an
 * older version of the configurations the version can be used to lookup and apply transformer functions
 * to get the newest version of the config from it.
 *
 * As more versions of configurations are added this type will have extra union types as part of SerialisedLayout.
 */
export type SerialisedLayout = {
    v: '1';
    c: ResolvedLayoutConfig;
};
/**
 * @public
 * The parameters that can be set on a new item when being added by the {@link FoundationLayout.addItem} API
 *
 * @remarks
 * `elements` - array of Elements that are the content of the new item
 * `title` - optional string which is used as the new title of the tab (defaults to be the registered name)
 * `closable` - optional boolean which allows the item to be closed with the X button if set and true
 * `size` - optional string describing the size of the new item (see the written documentation for more info)
 * `registration` - optional string configuring the registration ID of the new item (defaults to sequential IDs)
 */
export interface RegisteredElementConfig {
    registration: string;
    title?: string;
    closable?: boolean;
    size?: string;
}
/**
 * @public
 * Where to add the new item into the layout when using the {@link FoundationLayout.addItem} API
 */
export type Placement = {
    area: 'top' | 'left' | 'bottom' | 'right';
};
/** @internal */
export interface RegistrationConfig {
    elements: Element[];
    id?: string;
}
/** @internal */
export declare const layoutRegionValue: readonly ["horizontal", "vertical", "tabs"];
/**
 * @public
 * Union type describing the three different types of region splits.
 * Set on the `type` attribute on {@link FoundationLayoutRegion}.
 */
export type LayoutRegionType = (typeof layoutRegionValue)[number];
/** @internal */
export type ComponentTypes = LayoutRegionType | 'root' | 'item';
/** @internal */
export interface LayoutComponent {
    [componentType]: ComponentTypes;
    cacheElementsAndRegister(config: RegistrationConfig): string;
    requestLayoutReload(): void;
}
/** @internal */
export type AutosavedLayouts = {
    [x: string]: string;
};
//# sourceMappingURL=types.d.ts.map